@@ -1,19 +1,19 @@
 import click
 
-from ..config_generation import get_profiles_yml_build_path
+from ..config_generation import get_profiles_dir_build_path
 from ..dbt_utils import run_dbt_command
 from .compile import compile_project
 
 
 def run(env: str) -> None:
     """
-    Run the project on the local machine
+    Run the project on the local machine.
 
     :param env: Name of the environment
     :type env: str
     """
     compile_project(env)
-    profiles_path = get_profiles_yml_build_path(env)
+    profiles_path = get_profiles_dir_build_path(env)
     run_dbt_command(("run",), env, profiles_path)
 
 
